; Copyright (c) 1998, Theo Brauers, Forschungszentrum Juelich GmbH ICG-3
; All rights reserved. Unauthorized reproduction prohibited.
; This software may be used, copied, or redistributed as long as it is not
; sold and this copyright notice is reproduced on each copy made.  This
; routine is provided as is without any express or implied warranties
; whatsoever. Email bug reports to th.brauers@fz-juelich.de
;
;+
; NAME:
;   calc_modulo
;
; PURPOSE:
;   This function calcutes the modulo operator (not the MOD operator)
;
; CATEGORY:
;   MATH
;
; CALLING SEQUENCE:
;   Result = calc_modulo(number, base)
;
; INPUTS:
;   number: (array of) number to be divided
;   base:   divider
;
; OUTPUT:
;   This functions returns modulo(a,b) if possible, otherwise -1
;
; PROCEDURE:
;    modulo(a,b) = a - FLOOR(a/b)*b instead of
;    a MOD b = a - LONG(a/b)*b
;
; RESTRICTIONS:
;   Since the FLOOR funtion returns a LONG number this routine works
;   correctly only if ABS(a/b) LT MAXLONG.
;   Also take care of the precission of float and integer as input
;   i.e.
;       calc_modulo(DINDGEN(8)-4d9,3.D) works correctly
;       calc_modulo(DINDGEN(8)-4d9,3)   fails
;
; REVISION HISTORY:
;   Written     Theo Brauers, Nov 2000
;-
FUNCTION calc_modulo, a, b
idx = ABS(a/b) LE 2147483647L
IF TOTAL(idx) LT N_ELEMENTS(a) THEN $
    MESSAGE, /INFO, 'out of range, check input'
RETURN, idx *(a - b*FLOOR(a/b)) + (idx NE 1) * (-1)
END