function snidbin, w, f, nw, w0, dwlog, fnu=fnu, flambda=flambda, wbin=wbin, fsig=fsig, binfsig=binfsig

;
; Bin spectrum on log wavelength scale
;
;set /fnu if input spectrum is in F_nu units
;set /flambda to output flux per unit wavelength (as opposed to
;integrated flux in each bin)
;fsig is the sigma spectrum corresponding to fd

;log wavelength array
wbin = w0*exp(indgen(nw+1)*dwlog)                 ;nw+1 bin edges
dwbin = wbin-shift(wbin,1)                        ;bin sizes
dwbin = dwbin[1:nw]
for i=0, nw-1 do wbin[i]=0.5*(wbin[i]+wbin[i+1])  ;nw bin centers
wbin = wbin[0:nw-1]

;declare output flux array
fbin = fltarr(nw)
if keyword_set(fsig) then binfsig = fltarr(nw)

for l=0L, n_elements(w)-1 do begin
 
   ;Give each source pixel boundaries half way between tabulated wavelengths
    if (l eq 0) then begin
        s0 = 0.5*(3*w[l]-w[l+1])
        s1 = 0.5*(w[l]+w[l+1])
    endif else if (l eq n_elements(w)-1) then begin
        s0 = 0.5*(w[l-1]+w[l])
        s1 = 0.5*(3*w[l]-w[l-1])
    endif else begin
        s0 = 0.5*(w[l-1]+w[l])
        s1 = 0.5*(w[l]+w[l+1])
    endelse
    
    ;What do these boundaries map to in log wavelength array space
    s0log = alog(s0/w0)/dwlog
    s1log = alog(s1/w0)/dwlog
    if keyword_set(fnu) then $
      dw = (s1-s0)*2.99793e10/(w[l]*w[l]*1e-8) else $
      dw = s1-s0
    
    ;Run over rebinning loop
    for i=long(s0log), long(s1log) do begin
        if(i ge 0 and i lt nw-1) then begin
            alen = min([s1log,float(i+1)]) - max([s0log,float(i)])
            flux = f[l] * alen/(s1log-s0log) * dw
            fbin[i] = fbin[i] + flux
            if keyword_set(fsig) then begin
                sigflux = fsig[l] * alen/(s1log-s0log) * dw
                binfsig[i] = binfsig[i] + sigflux^2
            endif
        endif
    endfor

endfor

if keyword_set(fsig) then binfsig = sqrt(binfsig)

if keyword_set(flambda) then begin
    fbin = fbin/dwbin
    if keyword_set(fsig) then binfsig = binfsig/dwbin
endif

return, fbin
end
