function snidfilt, x, k1=k1, k2=k2, k3=k3, k4=k4

;
; Filter a real function in Fourier space. The bandpass filter is a
; cosine bell B(k1,k2,k3,k4)
;

n = n_elements(x)
if not keyword_set(k1) then k1 = 1
if not keyword_set(k2) then k2 = 4
if not keyword_set(k3) then k3 = n / 12
if not keyword_set(k4) then k4 = n / 10

;;; forward transform 
xft = fft(x, -1)

;;; apply bandpass filter
for j=1L, n do begin
    if j lt n/2+1 then $
      number = j - 1 else $
      number = j - n - 1
    numa = abs(number)
    if numa lt k1 or numa gt k4 then begin
        factor = 0
    endif else if numa lt k2 then begin
        arg = !pi * float(numa-k1)/float(k2-k1)
        factor = .5 * (1-cos(arg))
    endif else if numa gt k3 then begin
        arg = !pi * float(numa-k3)/float(k4-k3)
        factor = .5 * (1+cos(arg))
    endif else begin
        factor = 1
    endelse
    xft[j-1] = xft[j-1] * factor
endfor

;;; inverse transform
ffilt = float(fft(xft, 1))

return, ffilt
end
